@@ -158,9 +158,15 @@ class TradableType(Enum):
     #: A股(中国)
     #: China stock
     stock = "stock"
+    #: A股板块(中国)
+    #: China stock block
+    block = "block"
     #: 美股
     #: USA stock
     stockus = "stockus"
+    #: 美股指数
+    #: USA index
+    indexus = "indexus"
     #: 港股
     #: Hongkong Stock
     stockhk = "stockhk"
@@ -186,6 +192,8 @@ class Exchange(Enum):
 
     #: 对于中国的非交易所的 标的
     cn = "cn"
+    #: 对于美国的非交易所的 标的
+    us = "us"
 
     #: 纳斯达克
     nasdaq = "nasdaq"
@@ -211,9 +219,11 @@ class Exchange(Enum):
 
 
 tradable_type_map_exchanges = {
+    TradableType.block: [Exchange.cn],
     TradableType.stock: [Exchange.sh, Exchange.sz],
     TradableType.stockhk: [Exchange.hk],
     TradableType.stockus: [Exchange.nasdaq, Exchange.nyse],
+    TradableType.indexus: [Exchange.us],
     TradableType.future: [Exchange.shfe, Exchange.dce, Exchange.czce, Exchange.cffex],
     TradableType.coin: [Exchange.binance, Exchange.huobipro],
 }
