@@ -18,6 +18,18 @@ from .em_stockhk_meta_recorder import __all__ as _em_stockhk_meta_recorder_all
 
 __all__ += _em_stockhk_meta_recorder_all
 
+# import all from submodule em_block_meta_recorder
+from .em_block_meta_recorder import *
+from .em_block_meta_recorder import __all__ as _em_block_meta_recorder_all
+
+__all__ += _em_block_meta_recorder_all
+
+# import all from submodule em_indexus_meta_recorder
+from .em_indexus_meta_recorder import *
+from .em_indexus_meta_recorder import __all__ as _em_indexus_meta_recorder_all
+
+__all__ += _em_indexus_meta_recorder_all
+
 # import all from submodule em_stock_meta_recorder
 from .em_stock_meta_recorder import *
 from .em_stock_meta_recorder import __all__ as _em_stock_meta_recorder_all
